#!/bin/bash
# This is a script to build a Zenwalk package. Check the Zenwalk homepage: www.zenwalk.org
#
# SOFTWARE			: enblend-enfuse
# MAINTAINER       	: skywatcher (s.skywatcher|AT|gmail|DOT|org, simone antoniucci)
# LATEST REVISION	: 2011-04-01
# BUILD-ONLY DEPS	: tidy and transfig if one wants all documentation
# NOTES				: -

### Checking for unbound variables and exit on errors
set -u -e

### Repo
URL=http://zenwalk.pinguix.com/user-accounts/skywatcher

### Pkg variables
NAME="enblend-enfuse"
VERSION="4.0"
ARCH="i486"
CPU="i686"
BUILD="70.1"
EXT="txz"
HOMEPAGE="http://enblend.sourceforge.net"
SRCLNK="http://downloads.sourceforge.net/enblend/$NAME-$VERSION.tar.gz"
DESCRIPTION="Tool for blending and fusing images"
DOCS="AUTHORS COPYING ChangeLog INSTALL NEWS README* VIGRA_LICENSE"
ADDSRC="libpng14-fix.patch"
INCSRC=""
ADDDEP=""
XCLDEP=""

### Script variables
CWD=`pwd`
PKG=$NAME-$VERSION-$ARCH-$BUILD
URL=$URL/$NAME/$VERSION
PKGDIR=$CWD/$NAME-install
SRCDIR=$CWD/$NAME-$VERSION
SRCPKG=`echo $SRCLNK | cut -d\  -f1 | rev | cut -d/ -f1 | rev`

### Flags and jobs
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
NJOBS="-j4"

### Cleaning
rm -rf $PKGDIR
rm -rf $SRCDIR

### Making default package dirs
install -dv $SRCDIR $PKGDIR/{install,usr/src/$NAME-$VERSION}

### Getting sources
for src in $SRCLNK; do \
	source=`echo $src | rev | cut -d/ -f1 | rev` 
	if [ -f $source ]; then
		echo "Source file $source is already present, no need to download it";
	else
		echo "Downloading $source..."
		wget -c -nv $SRCLNK
	fi
done

### Extracting main sources
tar xfv $SRCPKG -C $SRCDIR --strip-components=1

### Building ===========================================================
cd $SRCDIR

patch -p1 < $CWD/libpng14-fix.patch

# Compiling and installing
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var --mandir=/usr/man --docdir=/usr/doc/$NAME-$VERSION \
|| exit 1
make $NJOBS || exit 1
make install DESTDIR=$PKGDIR || exit 1

# Icon

# Desktop entry

# Docs, man, info
cd $SRCDIR
install -dv $PKGDIR/usr/doc/$NAME-$VERSION
install -v $DOCS $PKGDIR/usr/doc/$NAME-$VERSION

#infodir=`find $PKGDIR -type d -name info`
#new_infodir=`echo $infodir | sed s:"share":"":`
#mv -v $infodir $new_infodir 

# Unnedeed stuff
#rm -frv $PKGDIR/usr/info/dir

### Slack-desc 
#    |-----handy-ruler------------------------------------------------------|
cat > $PKGDIR/install/slack-desc << EOF
$NAME: $NAME - $DESCRIPTION
$NAME:  
$NAME: Enblend is a tool for compositing images. Given a set of images that
$NAME: overlap in some irregular way, Enblend overlays them in such a way 
$NAME: that the seam between the images is invisible, or at least very 
$NAME: difficult to see. Enfuse is a tool for automatic exposure blending 
$NAME: and focus stack creation. Enblend and enfuse do not line up the 
$NAME: images for you. Use a tool like Hugin to do that. 
$NAME: 
$NAME: 
$NAME: $HOMEPAGE
EOF

### Doinstall
# infodir 
cat > $PKGDIR/install/doinst.sh << EOF
if [ -x usr/bin/install-info ]
then
   usr/bin/install-info --info-dir=usr/info usr/info/enfuse.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=usr/info usr/info/enblend.info.gz 2>/dev/null
   usr/bin/install-info --info-dir=usr/info usr/info/enbfuse-focus-stacking.info.gz 2>/dev/null
fi
EOF

# ======================================================================

### Managing and zipping man and info files
if [ -d $PKGDIR/usr/man ]; then
	find $PKGDIR/usr/man -type f -exec gzip -9 -v {} \;
fi
if [ -d $PKGDIR/usr/info ]; then
	find $PKGDIR/usr/info -type f -exec gzip -9 -v {} \;
fi

### Adding build-file and included stuff to the package
for file in $0 $INCSRC
	do cp -av $CWD/$file $PKGDIR/usr/src/$NAME-$VERSION
done
chmod a+x $PKGDIR/usr/src/$NAME-$VERSION/build-$NAME.sh

### Stripping binaries
cd $PKGDIR
set +e
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

### Ownerships and permissions
cd $PKGDIR
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
set -e

### Making the package
makepkg -l y -c n $CWD/$PKG.$EXT
cd $CWD

### md5
md5sum $PKG.$EXT > $PKG.md5

### dep
ADD=$ADDDEP EXCLUDE=$XCLDEP requiredbuilder -z $PKG.$EXT > $PKG.dep

### slackdesc
cat $PKGDIR/install/slack-desc > $PKG.txt

### src
echo $SRCLNK > $PKG.src
for link in $0 $ADDSRC 
	do echo $URL/$link >> $PKG.src
done

### Cleaning
DEL_SRCDIR=${DEL_SRCDIR-1}
if [ "$DEL_SRCDIR" -eq "1" ]; then
	rm -rf $SRCDIR
	rm -rf $PKGDIR
fi

### Done. Ciao!
